/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


import jama.Matrix;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;

import jgromacs.io.IOMath;

import junit.framework.TestCase;

import org.junit.Test;

public class IOMathTest extends TestCase{

	@Test
	public void testReadArrayListFromFile() {
		
		try {
			
			ArrayList<Double> alist = IOMath.readArrayListFromFile("dataset//example_array.txt");
			
			assertEquals(78, alist.size());
			
			assertEquals(0.460072128750844,(Double)alist.get(0),0.0000001);
			assertEquals(0.14039750927073025,(Double)alist.get(12),0.0000001);	
			assertEquals(0.44965361974970464,(Double)alist.get(52),0.0000001);
			
			} catch (IOException e) {
				fail(e.toString());
			}
		
	}

	@Test
	public void testReadMatrixFromFile() {
		try {
			
			Matrix M = IOMath.readMatrixFromFile("dataset//example_matrix.txt");
			
			assertEquals(90, M.getRowDimension());
			assertEquals(120, M.getColumnDimension());
			
			assertEquals(0.9262824199721511, M.get(0, 0), 0.0000001);
			assertEquals(0.4616256601617308, M.get(44, 102), 0.0000001);
			assertEquals(0.0935690188573769, M.get(79, 23), 0.0000001);
			
			} catch (IOException e) {
				fail(e.toString());
			}
	}

	
	@Test
	public void testWriteArrayListToFile() {
		try {
			
			ArrayList<Double> alist = IOMath.readArrayListFromFile("dataset//example_array.txt");
			
			IOMath.writeArrayListToFile(alist, "temparray.txt");
			
			ArrayList<Double> alist2 = IOMath.readArrayListFromFile("temparray.txt");
			
			assertEquals(alist, alist2); // Comparison
			
			File f = new File("temparray.txt");
			f.delete(); // Removing temporary file
			
			} catch (IOException e) {
				fail(e.toString());
			}
	}

	@Test
	public void testWriteMatrixToFile() {
		try {
			
			Matrix M = IOMath.readMatrixFromFile("dataset//example_matrix.txt");
			
			IOMath.writeMatrixToFile(M, "tempmatrix.txt");
			
			Matrix M2 = IOMath.readMatrixFromFile("tempmatrix.txt");
			
			// Comparison
			assertEquals(M.getRowDimension(), M2.getRowDimension());
			assertEquals(M.getColumnDimension(), M2.getColumnDimension());
			for (int i = 0; i < M.getRowDimension(); i++) {
				for (int j = 0; j < M.getColumnDimension(); j++) {
					assertEquals(M.get(i, j), M2.get(i, j),0.0000001);
				}	
			}
			
			File f = new File("tempmatrix.txt");
			f.delete(); // Removing temporary file
			
			} catch (IOException e) {
				fail(e.toString());
			}
	}

}
