/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


import jama.Matrix;
import jgromacs.data.Point3D;
import junit.framework.TestCase;

import org.junit.Test;

public class Point3DTest extends TestCase {

	@Test
	public void testDistance() {

		Point3D x = new Point3D(1,1,1);
		Point3D y = new Point3D(6,7,8);
		
		assertEquals(10.488088481702, x.distance(y), 0.0000001);
		
	}

	@Test
	public void testPlus() {
		
		Point3D x = new Point3D(-1,4,3);
		Point3D y = new Point3D(6,-2,9);
		
		assertEquals(new Point3D(5,2,12), x.plus(y));
	}

	@Test
	public void testMinus() {
		
		Point3D x = new Point3D(-1,4,3);
		Point3D y = new Point3D(6,-2,9);
		
		assertEquals(new Point3D(-7,6,-6), x.minus(y));
	}

	@Test
	public void testInnerProduct() {

		Point3D x = new Point3D(-1,4,3);
		Point3D y = new Point3D(6,-2,9);
		
		assertEquals(13.0, x.innerProduct(y), 0.00000001);
		
	}

	@Test
	public void testCrossProduct() {
		
		Point3D x = new Point3D(-1,4,3);
		Point3D y = new Point3D(6,-2,9);
		
		assertEquals(new Point3D(42,27,-22), x.crossProduct(y));
	}

	@Test
	public void testMultiplyByScalar() {
		
		Point3D x = new Point3D(-1,4,3);
		
		assertEquals(new Point3D(2.5,-10,-7.5), x.multiplyByScalar(-2.5));
	}

	@Test
	public void testLength() {
		
		Point3D x = new Point3D(6,-2,9);
		
		assertEquals(11.0, x.length(),0.0000001);
	}

	@Test
	public void testTransformByMatrix() {
		
		Point3D x = new Point3D(6,-2,9);
		Matrix M = new Matrix(3,3,0);
		
		M.set(0, 0, -2);
		M.set(0, 1, 1);
		M.set(0, 2, 3);
		M.set(1, 0, 4);
		M.set(1, 1, -3);
		M.set(1, 2, 5);
		M.set(2, 0, 0);
		M.set(2, 1, 6);
		M.set(2, 2, 1);
		
		assertEquals(new Point3D(13,75,-3), x.transformByMatrix(M));
	}
	
	@Test
	public void testCloneEquals() {
		
		Point3D x = new Point3D(6,-2,9);
		
		Point3D cx = (Point3D)x.clone();
		
		assertTrue(x.equals(cx));
		assertTrue(x!=cx);
		
		x.setX(2);
		assertTrue(!x.equals(cx));
		
	}

}
